@@ -5,21 +5,17 @@
 #' La ENIGH provee informacion estadisticas sobre los ingresos y gastos de los hogares en cuanto a su monto, procedencia y distribucion. Adicionalmente, la ENIGH provee informacion sobre las caracteristicas socio-demograficas de los integrantes del hogar.
 #'
 #' @param year Año de levantamiento de la encuesta en formato numerico. Los años disponibles son 2008, 2010, 2012 y 2014
-#' @param hogares Base de datos: caracteristicas de los hogares que habitan los integrantes de los mismos.
-#' @param concentrado Base de datos: principales variables por hogar. Contiene un resumen de variables de otras tablas.
-#' @param erogaciones Base de datos: erogaciones financieras y de capital realizadas por hogar.
-#' @param gastohogar 	Base de datos: gGastos monetarios y no monetarios del hogar.
-#' @param gastotarjetas Base de datos: financiamiento de tarjeta de credito bancaria o comercial.
-#' @param poblacion Base de datos: caracteristicas sociodemograficas de los integrantes del hogar.
-#' @param ingresos Base de datos: ingresos y percepciones financieras y de capital de cada uno de los integrantes del hogar, por diversos conceptos.
-#' @param gastopersona Base de datos: gastos realizados por cada integrante del hogar en educacion, transporte publico y remuneraciones en especie.
-#' @param trabajos Base de datos: actividad de los integrantes del hogar de 12 o mas años.
-#' @param agro Base de datos: informacion de los trabajadores independientes dedicados a las actividades agricolas, pesca, caza, etc.
-#' @param noagro Base de datos: informacion de los trabajadores independientes que tienen negocios en el hogar dedicados a las actividades industriales, comerciales y de servicios.
+#' @param datos Base de datos a descargar "viviendas" "hogares" "concentrado" "erogaciones" "gastohogar" "gastotarjetas" "poblacion" "ingresos" "gastopersona" "trabajos" "agro" "noagro"
+#' @examples
+#'
+#' # Descargar datos de hogares
+#' \donttest{hogares14 = enigh_nuevaconstruccion(year = 2014,  datos = "hogares")}
+#' @return Data.frame
 #' @export
 
 
-enigh_nuevaconstruccion = function(year = NA, hogares = FALSE, concentrado = FALSE, erogaciones = FALSE, gastohogar = FALSE, gastotarjetas = FALSE, poblacion = FALSE, ingresos = FALSE, gastopersona = FALSE, trabajos = FALSE, agro = FALSE, noagro = FALSE){
+enigh_nuevaconstruccion = function(year = NA, datos = NA){
+
 # General
 enigh.nueva.base = "https://www.inegi.org.mx/contenidos/programas/enigh/nc/"
 nuevaconstruccion = "NCV"
@@ -35,24 +31,24 @@ formato_archivo = "dbf"
 if (year == 2012) {nuevaconstruccion = tolower(nuevaconstruccion)} else{}
 
 ### 2.1 Viviendas  -----------------------------------------------------------------
+    if (datos == "viviendas" | (datos == "hogares" & (year ==2010 | year == 2008))) { # Las bases de datos de vivienda y hogares estan unidas para los an~os 2010 y 2008.
+        # Descargar archivo
+        vivienda = "NCV_Vivi_"
+        if (year == 2012) {vivienda = "ncv_viviendas_"} else if (year == 2010 | year == 2008) {vivienda = "NCV_Hogares_"} else {}
+        url.vivienda = paste0(url.base, vivienda, year, "_concil_2010_", formato_archivo, ".zip")
+        utils::download.file(url.vivienda, temp.enigh)
 
-# Descargar archivo
-vivienda = "NCV_Vivi_"
-if (year == 2012) {vivienda = "ncv_viviendas_"} else if (year == 2010 | year == 2008) {vivienda = "NCV_Hogares_"} else {}
-url.vivienda = paste0(url.base, vivienda, year, "_concil_2010_", formato_archivo, ".zip")
-utils::download.file(url.vivienda, temp.enigh)
-
-# Unzip y abrir
-utils::unzip(temp.enigh, exdir = zipdir)
-if (year == 2012) {vivienda = "NCV_viviendas_"} else if (year == 2010 | year == 2008) {vivienda = "NCV_Hogares_"} else {}
-ruta_vivienda = paste0(zipdir, "\\\\", vivienda, year, "_concil_2010")
-if (year == 2010 | year == 2008) {ruta_vivienda =  paste0(ruta_vivienda, "_DBF")} else {}
-data.enigh = foreign::read.dbf(paste0(ruta_vivienda, ".", formato_archivo), as.is = TRUE)
-names(data.enigh) = tolower(names(data.enigh))
+        # Unzip y abrir
+        utils::unzip(temp.enigh, exdir = zipdir)
+        if (year == 2012) {vivienda = "NCV_viviendas_"} else if (year == 2010 | year == 2008) {vivienda = "NCV_Hogares_"} else {}
+        ruta_vivienda = paste0(zipdir, "\\\\", vivienda, year, "_concil_2010")
+        if (year == 2010 | year == 2008) {ruta_vivienda =  paste0(ruta_vivienda, "_DBF")} else {}
+        data.enigh = foreign::read.dbf(paste0(ruta_vivienda, ".", formato_archivo), as.is = TRUE)
+        names(data.enigh) = tolower(names(data.enigh))
+    }
 
 ### 2.1.1 Hogares  ----------------------------------------------------------------
-  if (hogares == TRUE & (year ==2010 | year == 2008)) {} # Las bases de datos de vivienda y hogares estan unidas para los an~os 2010 y 2008.
-  else if (hogares == TRUE) {
+   if (datos == "hogares") {
       hogares = "NCV_Hogares_"
       # Descargar Datos
       #Sys.sleep(sample(1:3, 1)) # Some sleeping time
@@ -63,13 +59,14 @@ names(data.enigh) = tolower(names(data.enigh))
       utils::unzip(temp.enigh, exdir = zipdir)
       data.enigh.N2 = foreign::read.dbf(paste0(zipdir, "\\\\", hogares, year, "_concil_2010_", formato_archivo, ".", formato_archivo),as.is = TRUE)
       names(data.enigh.N2) = tolower(names(data.enigh.N2))
-      data.enigh    = dplyr::full_join(data.enigh, data.enigh.N2, by="folioviv", type="left", match="all")
-} # End of Nest 2: Hogares
+      #data.enigh    = merge(data.enigh, data.enigh.N2)
+      data.enigh     = data.enigh.N2
+   } # End Hogares
 ### 2.1.1.1 Hogares -> Concentrado Hogar  ----------------------------------------------------
-      if (concentrado == TRUE & erogaciones == FALSE & gastohogar == FALSE & gastotarjetas == FALSE & poblacion == FALSE){
+      else if (datos == "concentrado") {
 
         # Descargar Datos
-        Sys.sleep(sample(1:3, 1)) # Some sleeping time
+        #Sys.sleep(sample(1:2, 1)) # Some sleeping time
         Concentrado = "_Concentrado_"
         url.concentrado = paste0(url.base, toupper(nuevaconstruccion), Concentrado, year, "_concil_2010_", formato_archivo, ".zip")
         utils::download.file(url.concentrado, temp.enigh)
@@ -81,12 +78,13 @@ names(data.enigh) = tolower(names(data.enigh))
         if (year == 2010 | year == 2008) {ruta_nest3 =  paste0(ruta_nest3, "_DBF")} else {}
         data.enigh.N3 = foreign::read.dbf(paste0(ruta_nest3, ".", formato_archivo), as.is = TRUE)
         names(data.enigh.N3) = tolower(names(data.enigh.N3))
-        if (hogares == TRUE) {data.enigh = dplyr::full_join(data.enigh, data.enigh.N3, by=c("folioviv", "foliohog"), type="left", match="all")}
-        else if (hogares == FALSE) {data.enigh = data.enigh.N3}
+        #if (hogares == TRUE) {data.enigh = merge(data.enigh.N2, data.enigh.N3)}
+        data.enigh = data.enigh.N3
+        #else {}
       } # End of Nest 3: Concentrado Hogar
 
 ### 2.1.1.2 Hogares -> Erogaciones  -----------------------------------------------------------
-      else if (erogaciones == TRUE & concentrado == FALSE & gastohogar == FALSE & gastotarjetas == FALSE & poblacion == FALSE){
+      else if (datos == "erogaciones"){
 
         # Descargar archivos
         #Sys.sleep(sample(1:3, 1))
@@ -100,12 +98,12 @@ names(data.enigh) = tolower(names(data.enigh))
         if (year == 2010 | year == 2008) {ruta_nest3 = paste0(zipdir, "\\\\", toupper(nuevaconstruccion), Erogaciones, year, "_concil_2010_", toupper(formato_archivo))} else {}
         data.enigh.N3 = foreign::read.dbf(paste0(ruta_nest3, ".", formato_archivo), as.is = TRUE)
         names(data.enigh.N3) = tolower(names(data.enigh.N3))
-        if (hogares == TRUE) {data.enigh = dplyr::full_join(data.enigh, data.enigh.N3, by=c("folioviv", "foliohog"), type="left", match="all")}
-        else if (hogares == FALSE) {data.enigh = data.enigh.N3}
-      } # Endo of Nest 3: Erogaciones
+        #if (hogares == TRUE) {data.enigh = dplyr::full_join(data.enigh, data.enigh.N3, by=c("folioviv", "foliohog"), type="left", match="all")}
+        data.enigh = data.enigh.N3
+      } # Endo of Erogaciones
 
 ### 2.1.1.3 Hogares -> Gasto en el Hogar  ------------------------------------------------------------------
-      else if (gastohogar  == TRUE & concentrado == FALSE & erogaciones == FALSE & gastotarjetas == FALSE & poblacion == FALSE){
+      else if (datos == "gastohogar") {
 
         # Descargar datos
         #Sys.sleep(sample(1:3, 1))
@@ -120,12 +118,12 @@ names(data.enigh) = tolower(names(data.enigh))
         else if (year == 2010 | year == 2008) {ruta_nest3 = paste0(zipdir, "\\\\", toupper(nuevaconstruccion), "_Gastos_", year, "_concil_2010_", toupper(formato_archivo))} else {}
         data.enigh.N3 = foreign::read.dbf(paste0(ruta_nest3, ".", formato_archivo), as.is = TRUE)
         names(data.enigh.N3) = tolower(names(data.enigh.N3))
-        if (hogares == TRUE) {data.enigh = dplyr::full_join(data.enigh, data.enigh.N3, by=c("folioviv", "foliohog"), type="left", match="all")}
-        else if (hogares == FALSE) {data.enigh = data.enigh.N3}
-      } # End of Nest 3: Gasto Hogar
+        #if (hogares == TRUE) {data.enigh = dplyr::full_join(data.enigh, data.enigh.N3, by=c("folioviv", "foliohog"), type="left", match="all")}
+        data.enigh = data.enigh.N3
+      } # End of Gasto Hogar
 
 ### 2.1.1.4 Hogares -> Gasto Tarjetas  -----------------------------------------------------------------
-      else if (gastotarjetas == TRUE & concentrado == FALSE & erogaciones == FALSE & gastohogar == FALSE & poblacion == FALSE){
+      else if (datos == "gastotarjetas") {
 
         # Descargar datos
         #Sys.sleep(sample(1:3, 1))
@@ -135,16 +133,16 @@ names(data.enigh) = tolower(names(data.enigh))
 
         # Unzip y abrir
         utils::unzip(temp.enigh, exdir = zipdir)
-        if (year == 2014 | year == 2012) {ruta_nest3 = paste0(zipdir, "\\\\", tolower(nuevaconstruccion), tolower(gasto_tarjetas), year, "_concil_2010_", formato_archivo)} else {}
-        if (year == 2010 | year == 2008) {ruta_nest3 = paste0(zipdir, "\\\\", toupper(nuevaconstruccion), gasto_tarjetas, year, "_concil_2010_", toupper(formato_archivo))} else {}
+        if (year == 2014 | year == 2012) {ruta_nest3 = paste0(zipdir, "\\\\", tolower(nuevaconstruccion), tolower(gasto_tarjetas), year, "_concil_2010_", formato_archivo)}
+        else if (year == 2010 | year == 2008) {ruta_nest3 = paste0(zipdir, "\\\\", toupper(nuevaconstruccion), gasto_tarjetas, year, "_concil_2010_", toupper(formato_archivo))} else {}
         data.enigh.N3 = foreign::read.dbf(paste0(ruta_nest3, ".", formato_archivo), as.is = TRUE)
         names(data.enigh.N3) = tolower(names(data.enigh.N3))
-        if (hogares == TRUE) {data.enigh = dplyr::full_join(data.enigh, data.enigh.N3, by=c("folioviv", "foliohog"), type="left", match="all")}
-        else if (hogares == FALSE) {data.enigh = data.enigh.N3}
-      } # End of Nest 3: Gasto Tarjetas
+        #if (hogares == TRUE) {data.enigh = dplyr::full_join(data.enigh, data.enigh.N3, by=c("folioviv", "foliohog"), type="left", match="all")}
+        data.enigh = data.enigh.N3
+      } # End Gasto Tarjetas
 
 ### 2.1.1.5 Hogares -> Poblacion  ----------------------------------------------------------------------
-      else if (poblacion == TRUE & concentrado == FALSE & erogaciones == FALSE & gastohogar == FALSE & gastotarjetas == FALSE){
+      else if (datos == "poblacion"){
 
         # Descargar datos
         #Sys.sleep(sample(1:3, 1))
@@ -155,15 +153,18 @@ names(data.enigh) = tolower(names(data.enigh))
         # Unzip y abrir
         utils::unzip(temp.enigh, exdir = zipdir)
         if (year == 2014 | year == 2012) {ruta_nest3 = paste0(zipdir, "\\\\", tolower(nuevaconstruccion), tolower(Poblacion), year, "_concil_2010_", formato_archivo)}
-        else if (year == 2010 | year == 2008) {ruta_nest3 = paste0(zipdir, "\\\\", toupper(nuevaconstruccion), Poblacion, year, "_concil_2010_", toupper(formato_archivo))}
+        else if (year == 2010 | year == 2008) {ruta_nest3 = paste0(zipdir, "\\\\", toupper(nuevaconstruccion), Poblacion, year, "_concil_2010_", toupper(formato_archivo))} else {}
         data.enigh.N3 = foreign::read.dbf(paste0(ruta_nest3, ".", formato_archivo), as.is = TRUE)
         names(data.enigh.N3) = tolower(names(data.enigh.N3))
-        if (hogares == FALSE) {stop(message("Hogares debe ser TRUE"))}
-        data.enigh = data.table::data.table(data.enigh, key=c("folioviv", "foliohog"))[data.table::data.table(data.enigh.N3,key=c("folioviv", "foliohog")), allow.cartesian=TRUE]
+        #if (hogares == TRUE) {data.enigh = merge(data.enigh, data.enigh.N3)}
+        #if (hogares == TRUE) {data.enigh = data.table::data.table(data.enigh, key=c("folioviv", "foliohog"))[data.table::data.table(data.enigh.N3,key=c("folioviv", "foliohog")), allow.cartesian=TRUE]}
+        #if (hogares == TRUE) {data.enigh = data.table::data.table(data.enigh, key=c("folioviv", "foliohog"))[data.table::data.table(data.enigh.N3,key=c("folioviv", "foliohog")), allow.cartesian=TRUE]}
+        data.enigh = data.enigh.N3
+        } # End Poblacion
 
         ### Nest 4: Poblacion -> Ingresos  ---------------------------------------------------
-        if (ingresos == TRUE & poblacion == FALSE) {stop(message("Poblacion debe ser TRUE"))} else {}
-        if (ingresos == TRUE & gastopersona == FALSE & trabajos == FALSE){
+        #if (ingresos == TRUE & poblacion == FALSE) {stop(message("Poblacion debe ser TRUE"))} else {}
+        if (datos == "ingresos") {
 
           # Descargar datos
           #Sys.sleep(sample(1:3, 1))
@@ -177,13 +178,13 @@ names(data.enigh) = tolower(names(data.enigh))
           else if (year == 2010 | year == 2008) {ruta_nest4 = paste0(zipdir, "\\\\", toupper(nuevaconstruccion), n4_ingresos, year, "_concil_2010_", toupper(formato_archivo), ".", formato_archivo)} else {}
           data.enigh.N4 = foreign::read.dbf(ruta_nest4, as.is = TRUE)
           names(data.enigh.N4) = tolower(names(data.enigh.N4))
-          if (hogares == FALSE | poblacion == FALSE) {stop(message("Hogares y Poblacion deben ser TRUE"))}
-          data.enigh = data.table::data.table(data.enigh, key=c("folioviv", "foliohog", "numren"))[data.table::data.table(data.enigh.N4,key=c("folioviv", "foliohog", "numren")), allow.cartesian=TRUE]
-          if (poblacion == FALSE) {data.enigh = data.enigh.N4}
+          #if (hogares == FALSE | poblacion == FALSE) {stop(message("Hogares y Poblacion deben ser TRUE"))}
+          #data.enigh = data.table::data.table(data.enigh, key=c("folioviv", "foliohog", "numren"))[data.table::data.table(data.enigh.N4,key=c("folioviv", "foliohog", "numren")), allow.cartesian=TRUE]
+          data.enigh = data.enigh.N4
         } # End of Nest_4 Ingresos
 
         ### Nest 4: Poblacion -> Gastopersona  ----------------------------------------------
-        if (gastopersona == TRUE & ingresos == FALSE & trabajos == FALSE){
+        else if (datos == "gastopersona"){
 
           # Descargar datos
           #Sys.sleep(sample(1:3, 1))
@@ -197,12 +198,13 @@ names(data.enigh) = tolower(names(data.enigh))
           else if (year == 2010 | year == 2008) {ruta_nest4 = paste0(zipdir, "\\\\", toupper(nuevaconstruccion), n4_gastopersona, year, "_concil_2010_", toupper(formato_archivo), ".", formato_archivo)} else {}
           data.enigh.N4 = foreign::read.dbf(ruta_nest4, as.is = TRUE)
           names(data.enigh.N4) = tolower(names(data.enigh.N4))
-          if (hogares == FALSE | poblacion == FALSE) {stop(message("Hogares y Poblacion deben ser TRUE"))}
-          data.enigh = data.table::data.table(data.enigh, key=c("folioviv", "foliohog", "numren"))[data.table::data.table(data.enigh.N4,key=c("folioviv", "foliohog", "numren")), allow.cartesian=TRUE]
+          #if (hogares == FALSE | poblacion == FALSE) {stop(message("Hogares y Poblacion deben ser TRUE"))}
+          #data.enigh = data.table::data.table(data.enigh, key=c("folioviv", "foliohog", "numren"))[data.table::data.table(data.enigh.N4,key=c("folioviv", "foliohog", "numren")), allow.cartesian=TRUE]
+          data.enigh = data.enigh.N4
         } # End of Nest_4 Gasto Persona
 
         ### Nest 4: Poblacion - > Trabajos  -----------------------------------------------
-        if (trabajos == TRUE & ingresos == FALSE & gastopersona == FALSE){
+        else if (datos == "trabajos"){
 
           # Descargar
           #Sys.sleep(sample(1:3, 1))
@@ -216,14 +218,15 @@ names(data.enigh) = tolower(names(data.enigh))
           else if (year == 2010 | year == 2008) {ruta_nest4 = paste0(zipdir, "\\\\", toupper(nuevaconstruccion), n4_trabajos, year, "_concil_2010_", toupper(formato_archivo), ".", formato_archivo)} else {}
           data.enigh.N4 = foreign::read.dbf(ruta_nest4, as.is = TRUE)
           names(data.enigh.N4) = tolower(names(data.enigh.N4))
-          data.enigh = data.table::data.table(data.enigh, key=c("folioviv", "foliohog", "numren"))[data.table::data.table(data.enigh.N4,key=c("folioviv", "foliohog", "numren")), allow.cartesian=TRUE]
-          if (hogares == FALSE | poblacion == FALSE) {stop(message("Hogares o Poblacion deben ser TRUE"))}
-
+          #data.enigh = data.table::data.table(data.enigh, key=c("folioviv", "foliohog", "numren"))[data.table::data.table(data.enigh.N4,key=c("folioviv", "foliohog", "numren")), allow.cartesian=TRUE]
+          #if (hogares == FALSE | poblacion == FALSE) {stop(message("Hogares o Poblacion deben ser TRUE"))}
+          data.enigh = data.enigh.N4
           #data.enigh$fk_trabajo = paste0(as.character(data.enigh$id_renglon), as.character(data.enigh$id_trabajo))
+          } # End Trabajos
 
             ### ==========================================================================
             ### NEST 5: Poblacion -> Trabajos -> Agro  -----------------------------------
-            if (agro == TRUE & noagro == FALSE){
+            else if (datos == "agro"){
 
               # Descargar
               #Sys.sleep(sample(1:3, 1))
@@ -237,12 +240,13 @@ names(data.enigh) = tolower(names(data.enigh))
               else if (year == 2010 | year == 2008) {ruta_nest5 = paste0(zipdir, "\\\\", toupper(nuevaconstruccion), n5_agro, year, "_concil_2010_", toupper(formato_archivo), ".", formato_archivo)} else {}
               data.enigh.N5 = foreign::read.dbf(ruta_nest5, as.is = TRUE)
               names(data.enigh.N5) = tolower(names(data.enigh.N5))
-              data.enigh = data.table::data.table(data.enigh, key=c("folioviv", "foliohog", "numren", "id_trabajo"))[data.table::data.table(data.enigh.N5,key=c("folioviv", "foliohog", "numren", "id_trabajo")), allow.cartesian=TRUE]
-              if (trabajos == FALSE) {stop(message("Trabajos debe ser TRUE"))}
-            } # End of Nest 5: Agro
+              #data.enigh = data.table::data.table(data.enigh, key=c("folioviv", "foliohog", "numren", "id_trabajo"))[data.table::data.table(data.enigh.N5,key=c("folioviv", "foliohog", "numren", "id_trabajo")), allow.cartesian=TRUE]
+              #if (trabajos == FALSE) {stop(message("Trabajos debe ser TRUE"))}
+              data.enigh = data.enigh.N5
+            } # End of Agro
 
            ### Nest 5: Poblacion -> Trabajos -> NoAgro  --------------------------------
-            if (noagro == TRUE & agro == FALSE){
+            else if (datos == "noagro"){
 
               # Descargar
               #Sys.sleep(sample(1:3, 1))
@@ -256,12 +260,11 @@ names(data.enigh) = tolower(names(data.enigh))
               else if (year == 2010 | year == 2008) {ruta_nest5 = paste0(zipdir, "\\\\", toupper(nuevaconstruccion), n5_noagro, year, "_concil_2010_", toupper(formato_archivo), ".", formato_archivo)} else {}
               data.enigh.N5 = foreign::read.dbf(ruta_nest5, as.is = TRUE)
               names(data.enigh.N5) = tolower(names(data.enigh.N5))
-              data.enigh = data.table::data.table(data.enigh, key=c("folioviv", "foliohog", "numren", "id_trabajo"))[data.table::data.table(data.enigh.N5,key=c("folioviv", "foliohog", "numren", "id_trabajo")), allow.cartesian=TRUE]
-              if (trabajos == FALSE) {stop(message("Trabajos debe ser TRUE"))}
-            } # End of Nest 5: NoAgro
-        } # End Nest 4: Poblacion - > Trabajos
-      } #End of Nest 3: Poblacion
-      else if (concentrado == FALSE & erogaciones == FALSE & gastohogar == FALSE & gastotarjetas == FALSE & poblacion == FALSE) {}
-      else {stop(message("Dos o mas de los siguentes parametros no pueden ser TRUE al mismo tiempo: concentrado, erogaciones, gastohogar, gastotarjetas y poblacion."))}
-  return(data.enigh)
+              #data.enigh = data.table::data.table(data.enigh, key=c("folioviv", "foliohog", "numren", "id_trabajo"))[data.table::data.table(data.enigh.N5,key=c("folioviv", "foliohog", "numren", "id_trabajo")), allow.cartesian=TRUE]
+              #if (trabajos == FALSE) {stop(message("Trabajos debe ser TRUE"))}
+              data.enigh = data.enigh.N5
+            } # End of NoAgro
+
+if (exists("data.enigh")) {return(data.enigh)}
+else {stop(message("\nLa opcion tecleada en el parametro 'datos' es incorrecta."))}
 } # End of Function
